@@ -6,15 +6,15 @@
 #    By: juligonz <juligonz@student.42.fr>          +#+  +:+       +#+         #
 #                                                 +#+#+#+#+#+   +#+            #
 #    Created: 2020/07/15 18:24:43 by charles           #+#    #+#              #
-#    Updated: 2021/02/05 14:48:47 by charles          ###   ########.fr        #
+#    Updated: 2021/02/27 20:36:27 by cacharle         ###   ########.fr        #
 #    Updated: 2020/09/11 18:01:27 by juligonz         ###   ########.fr        #
 #                                                                              #
 # **************************************************************************** #
 
 import os
 
-import minishell_test.config as config
-import minishell_test.hooks as hooks
+from minishell_test.config import Config
+from minishell_test import hooks
 from minishell_test.suite.decorator import suite
 from minishell_test.hooks import linux_discard
 
@@ -26,12 +26,12 @@ def suite_echo(test):
     test("echo bonjour")
     test("echo lalalala lalalalal alalalalal alalalala")
     test("echo lalalala                lalalalal      alalalalal alalalala")
-    test("echo " + config.LOREM)
+    test("echo " + Config.lorem)
     test("echo -n")
     test("echo -n bonjour")
     test("echo -n lalalala lalalalal alalalalal alalalala")
     test("echo -n lalalala                lalalalal      alalalalal alalalala")
-    test("echo -n " + config.LOREM)
+    test("echo -n " + Config.lorem)
     test("echo bonjour -n")
     test("echo -n bonjour -n")
     test("                        echo                     bonjour             je")
@@ -168,7 +168,7 @@ def suite_cd(test):
     test("echo $PWD; echo $OLDPWD; cd /.; pwd; echo $PWD; echo $OLDPWD")
     test("echo $PWD; echo $OLDPWD; cd /./; pwd; echo $PWD; echo $OLDPWD")
     test("echo $PWD; echo $OLDPWD; cd /././././; pwd; echo $PWD; echo $OLDPWD")
-    test("echo $PWD; echo $OLDPWD; cd //; pwd; echo $PWD; echo $OLDPWD", hook=hooks.replace_double_slash)
+    test("echo $PWD; echo $OLDPWD; cd //; pwd; echo $PWD; echo $OLDPWD", hook=hooks.replace_double("/"))
     test("echo $PWD; echo $OLDPWD; cd ///; pwd; echo $PWD; echo $OLDPWD")
     test("echo $PWD; echo $OLDPWD; cd ////; pwd; echo $PWD; echo $OLDPWD")
     test("echo $PWD; echo $OLDPWD; cd //////////////////////////////////////////////////////; pwd; echo $PWD; echo $OLDPWD")
@@ -179,7 +179,7 @@ def suite_cd(test):
     test("echo $PWD; echo $OLDPWD; cd '                  /'; pwd; echo $PWD; echo $OLDPWD")
     test("echo $PWD; echo $OLDPWD; cd '                  /              '; pwd; echo $PWD; echo $OLDPWD")
     test("echo $PWD; echo $OLDPWD; cd ' // '; pwd; echo $PWD; echo $OLDPWD")
-    test("echo $PWD; echo $OLDPWD; cd //home; pwd; echo $PWD; echo $OLDPWD", hook=hooks.replace_double_slash)
+    test("echo $PWD; echo $OLDPWD; cd //home; pwd; echo $PWD; echo $OLDPWD", hook=hooks.replace_double("/"))
     test("echo $PWD; echo $OLDPWD; cd ' //home'; pwd; echo $PWD; echo $OLDPWD")
     test("echo $PWD; echo $OLDPWD; cd '     //home    '; pwd; echo $PWD; echo $OLDPWD")
     test("echo $PWD; echo $OLDPWD; cd d; echo $OLDPWD", setup="mkdir -m 000 d")
@@ -393,7 +393,7 @@ def suite_exit(test):
     test("exit bonjour 0", hook_status=hooks.platform_status(255, 2))
     test("exit 0 1")
     test("exit 0 1 2 3 4 5 6 7 8 9")
-    test("exit " + config.LOREM, hook_status=hooks.platform_status(255, 2))
+    test("exit " + Config.lorem, hook_status=hooks.platform_status(255, 2))
     test("exit bonjoru; echo should have exited", hook_status=hooks.platform_status(255, 2))
     test("exit 99999999999999999999999999999999999999999999999999999; echo should have exited", hook_status=hooks.platform_status(255, 2))
     test("exit 9999; echo should have exited")
