@@ -6,14 +6,14 @@
 #    By: charles <charles.cabergs@gmail.com>        +#+  +:+       +#+         #
 #                                                 +#+#+#+#+#+   +#+            #
 #    Created: 2020/07/15 15:11:46 by charles           #+#    #+#              #
-#    Updated: 2021/02/05 16:15:42 by charles          ###   ########.fr        #
+#    Updated: 2021/02/27 12:07:29 by cacharle         ###   ########.fr        #
 #                                                                              #
 # ############################################################################ #
 
 import distutils
 
-import minishell_test.hooks as hooks
-import minishell_test.config as config
+from minishell_test import hooks
+from minishell_test.config import Config
 from minishell_test.suite.decorator import suite
 
 
@@ -105,8 +105,8 @@ def suite_cmd(test):
          "asd f asd f asdf asdf  asdf  asd f asd f asd f asd f as df as df a"
          "asd f asd f asdf asdf  asdf  asd f asd f asd f asd f as df as df a"
          "asd f asd f asdf asdf  asdf  asd f asd f asd f asd f as df as df a")
-    test("echo " + config.LOREM * 10)
-    test("echo " + config.LOREM * 20)
+    test("echo " + Config.lorem * 10)
+    test("echo " + Config.lorem * 20)
 
 
 @suite()
