@@ -6,12 +6,12 @@
 #    By: juligonz <juligonz@student.42.fr>          +#+  +:+       +#+         #
 #                                                 +#+#+#+#+#+   +#+            #
 #    Created: 2020/07/15 18:25:00 by charles           #+#    #+#              #
-#    Updated: 2021/02/05 14:43:27 by charles          ###   ########.fr        #
+#    Updated: 2021/02/27 12:07:11 by cacharle         ###   ########.fr        #
 #                                                                              #
 # **************************************************************************** #
 
-import minishell_test.config as config
-import minishell_test.hooks as hooks
+from minishell_test.config import Config
+from minishell_test import hooks
 from minishell_test.suite.decorator import suite
 
 
@@ -128,9 +128,9 @@ def suite_interpolation(test):
     test('echo $A\\ ',   exports={"A": "bonjour     je     suis    splited"})
     test('echo $A\\ ',   exports={"A": "   bonjour     je     suis    splited   "})
     test('echo $A$A$A',  exports={"A": "   bonjour     je     suis    splited   "})
-    test("echo $A",      exports={"A": "'" + config.LOREM + "'"})
-    test('echo "$A"',    exports={"A": "'" + config.LOREM + "'"})
-    test("echo '$A'",    exports={"A": "'" + config.LOREM + "'"})
+    test("echo $A",      exports={"A": "'" + Config.lorem + "'"})
+    test('echo "$A"',    exports={"A": "'" + Config.lorem + "'"})
+    test("echo '$A'",    exports={"A": "'" + Config.lorem + "'"})
     test("$ECHO $ECHO",  exports={"ECHO": "echo"})
     test("$A$B bonjour", exports={"A": "ec", "B": "ho"})
     test("$LS",          exports={"LS": "ls -l"}, setup="touch a b c")
